@@ -20,6 +20,7 @@
 
 from __future__ import print_function, unicode_literals
 
+import mock
 import os
 import random
 import sys
@@ -165,12 +166,9 @@ class AccessControlTests(unittest.TestCase, BasicHelper):
     def setUp(self):
         self.configure()
 
-    def test_exception_get_flair_list_authenticated(self):
-        self.r.login(self.un, self.un_pswd)
-        self.assertTrue(self.r.get_flair_list(self.sr))
-
     def test_exception_get_flair_list_unauthenticated(self):
-        self.assertTrue(self.r.get_flair_list(self.sr))
+        self.assertRaises(errors.LoginOrScopeRequired, self.r.get_flair_list,
+                          self.sr)
 
     def test_login_or_oauth_required_not_logged_in(self):
         self.assertRaises(errors.LoginOrScopeRequired,
@@ -285,7 +283,8 @@ class BasicTest(unittest.TestCase, BasicHelper):
         self.assertEqual(num, len(list(result)))
 
     def test_get_flair_list(self):
-        sub = self.r.get_subreddit('python')
+        self.r.login(self.un, self.un_pswd)
+        sub = self.r.get_subreddit(self.sr)
         self.assertTrue(next(sub.get_flair_list()))
 
     def test_get_front_page(self):
@@ -329,6 +328,22 @@ class BasicTest(unittest.TestCase, BasicHelper):
         retreived = [x.fullname for x in self.r.get_submissions(fullnames)]
         self.assertEqual(fullnames, retreived)
 
+    @mock.patch.object(Reddit, 'request_json')
+    def test_get_submissions_with_params(self, mock_my_method):
+        fake_submission = Submission(self.r, {'permalink': 'meh', 'score': 2,
+                                              'title': 'test'})
+        mock_resp = ({'data': {'children': [fake_submission]}},
+                     {'data': {'children': []}})
+        mock_my_method.return_value = mock_resp
+        url = ("http://www.reddit.com/r/redditgetsdrawn/comments/"
+               "1ts9hi/surprise_me_thanks_in_advance/cec0897?context=3")
+        self.assertTrue(self.r.get_submission(url).score == 2)
+        self.assertTrue(self.r.get_submission(url).title == 'test')
+        base_url = ("http://www.reddit.com/r/redditgetsdrawn/comments/"
+                    "1ts9hi/surprise_me_thanks_in_advance/cec0897")
+        params = {"context": "3"}
+        mock_my_method.assert_called_with(base_url, params=params)
+
     def test_get_subreddit_recommendations(self):
         result = self.r.get_subreddit_recommendations('python')
         self.assertTrue(result)
@@ -936,7 +951,7 @@ class ImageTests(unittest.TestCase, AuthenticatedHelper):
     def test_upload_invalid_file_path(self):
         self.assertRaises(IOError, self.subreddit.upload_image, 'nonexistent')
 
-    def test_upload_invalid_image(self):
+    def test_upload_uerinvalid_image(self):
         image = self.image_path.format('white-square.tiff')
         self.assertRaises(errors.ClientException, self.subreddit.upload_image,
                           image)
@@ -1628,7 +1643,6 @@ class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
         self.configure()
 
     def test_clear_vote(self):
-        self.disable_cache()
         predicate = lambda submission: submission.likes is False
         submission = self.first(self.r.user.get_submitted(), predicate)
         submission.clear_vote()
@@ -1637,7 +1651,6 @@ class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
         self.assertEqual(submission.likes, None)
 
     def test_delete(self):
-        self.disable_cache()
         submission = list(self.r.user.get_submitted())[-1]
         submission.delete()
         # reload the submission
@@ -1645,7 +1658,6 @@ class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
         self.assertEqual(None, submission.author)
 
     def test_downvote(self):
-        self.disable_cache()
         predicate = lambda submission: submission.likes is True
         submission = self.first(self.r.user.get_submitted(), predicate)
         submission.downvote()
@@ -1675,7 +1687,6 @@ class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
         self.first(self.r.get_subreddit(self.sr).get_reports(), predicate)
 
     def test_save(self):
-        self.disable_cache()
         predicate = lambda submission: not submission.saved
         submission = self.first(self.r.user.get_submitted(), predicate)
         submission.save()
@@ -1724,7 +1735,6 @@ class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
         self.assertFalse(submission.hidden)
 
     def test_unsave(self):
-        self.disable_cache()
         predicate = lambda submission: submission.saved
         submission = self.first(self.r.user.get_submitted(), predicate)
         submission.unsave()
@@ -1733,7 +1743,6 @@ class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
         self.assertFalse(submission.saved)
 
     def test_upvote(self):
-        self.disable_cache()
         predicate = lambda submission: submission.likes is None
         submission = self.first(self.r.user.get_submitted(), predicate)
         submission.upvote()
